@@ -43,7 +43,7 @@ private Q_SLOTS:
         Control::start();
         // switch target resources offline to reduce interference from them
         foreach (Akonadi::AgentInstance agent, Akonadi::AgentManager::self()->instances()) {   //krazy:exclude=foreach
-            if (agent.identifier() == QStringLiteral("akonadi_knut_resource_2")) {
+            if (agent.identifier() == QLatin1String("akonadi_knut_resource_2")) {
                 agent.setIsOnline(false);
             }
         }
