@@ -146,7 +146,7 @@ void SetupTest::copyXdgDirectory(const QString &src, const QString &dst)
     const auto entries = srcDir.entryInfoList(QDir::Dirs | QDir::Files | QDir::NoSymLinks | QDir::NoDotAndDotDot);
     for (const auto &fi : entries) {
         if (fi.isDir()) {
-            if (fi.fileName() == QStringLiteral("akonadi")) {
+            if (fi.fileName() == QLatin1String("akonadi")) {
                 // namespace according to instance identifier
 #ifdef Q_OS_WIN
                 const bool isXdgConfig = src.contains(QLatin1String("/xdgconfig/"));
@@ -159,7 +159,7 @@ void SetupTest::copyXdgDirectory(const QString &src, const QString &dst)
                 copyDirectory(fi.absoluteFilePath(), dst + QLatin1Char('/') + fi.fileName());
             }
         } else {
-            if (fi.fileName().startsWith(QStringLiteral("akonadi_")) && fi.fileName().endsWith(QStringLiteral("rc"))) {
+            if (fi.fileName().startsWith(QLatin1String("akonadi_")) && fi.fileName().endsWith(QLatin1String("rc"))) {
                 // namespace according to instance identifier
                 const QString baseName = fi.fileName().left(fi.fileName().size() - 2);
                 const QString dstPath = dst + QLatin1Char('/') + Akonadi::ServerManager::addNamespace(baseName) + QStringLiteral("rc");
