@@ -24,7 +24,6 @@
 #include "entitydisplayattribute.h"
 
 #include <QTest>
-#include <QDebug>
 #include <QStringList>
 using namespace Akonadi;
 
@@ -76,7 +75,7 @@ void CollectionTest::testBuildCollection()
     verifyCollection(colist, 2, QStringLiteral("c112"), QStringLiteral("Akonadi"), mimeType);
 
     QVERIFY(colist.at(0).hasAttribute<EntityDisplayAttribute>());
-    EntityDisplayAttribute *attr = colist.at(0).attribute<EntityDisplayAttribute>();
+    const EntityDisplayAttribute *attr = colist.at(0).attribute<EntityDisplayAttribute>();
     QCOMPARE(attr->displayName(), QStringLiteral("Posteingang"));
 }
 
